# La charge électrique et le champs électrique

Les forces électriques sont omniprésentes dans notre vie de tous les jours.
Elles permettent d'allumer des ampoules, de faire fonctionner les 
ordinateurs, de faire tourner des moteurs, ... Elles sont aussi
responsables des interactions inter-atomiques pour que des amas d'atomes 
forment des solides ou les liquides. En réalité un certain nombre des
forces que nous avons considéré dans le chapitre précédent sont
le résultat des interactions électriques au niveau atomique (la force de
frottement par exemple).

## L'électricité statique et la conservation de la charge électrique

Lorsqu'on frotte un ballon de baudruche contre sa tête, on constate
que les cheveux ont tendances à rester attachés au ballon
plutôt que de tomber vers le sol sous l'effet de la gravité.
On dit aujourd'hui que les cheveux se dressent sous l'effet de l'**électricité statique**.
En réalité, sous l'effet du frottement, le ballon comme les cheveux deviennent "chargés":
ils possèdent une **charge électrique**.

Il existe *deux* types de charges électriques: la charge *positive* et la charge *négative*.
Des objets possédant une charge de *même* type ont tendance à se repousser,
alors que ceux possédant des charges *opposées*
ont tendance à s'attirer mutuellement.

L'expérience de charger un objet en le frottant peut amener à charger positivement ou 
négativement un objet. Ainsi, on dit qu'une baguette en verre est chargée *positivement*,
alors qu'une baguette en plastique est chargée *négativement*. Ce choit est totalement arbitraire
et a été choisi par B. Franklin (au 18e siècle) qui a été un des premiers à faire ce type d'expériences.

Avant de frotter ses cheveux contre un ballon et de rendre les cheveux et le ballon chargés,
on constate qu'il n'y a pas d'attraction particulière entre ces deux objets. Cela signifie
que ni l'un ni l'autre ne sont chargés. En fait le frottement va donner une charge 
*égale et opposée* à chaque objet.

Cela est une conséquence de la loi de la conservation de la charge électrique qui dit que

* La charge totale produite par un processus est nulle,

ou en d'autres termes

* Aucune charge ne peut être créée ou détruite.

En pratique cela signifie que si une région de l'espace acquière une charge positive,
une autre région aura acquis dans le même temps la même charge mais négative.

---

Question (D'autres lois de conservation) #

Connaissez-vous d'autres lois de conservation?

---

---

Réponse (D'autres lois de conservation) #

La conservation de l'énergie, de la masse, de la quantité de mouvement, ...

---

## La charge électrique dans les atomes

Un modèle simplifié d'un atome postule qu'un atome possède un noyau chargé positivement (composé de 
protons et de neutrons, ces derniers n'ont pas de charge) autour duquel tournent les électrons chargés négativement (voir @fig:bohr). Les protons ont exactement la même charge électrique que les électrons
mais inversée. Ainsi les atomes n'ont pas une charge nette.

![Illustration du modèle de l'atome de Bohr. Source: 
[Wikipedia](https://upload.wikimedia.org/wikipedia/commons/2/2c/Blausen_0342_ElectronEnergyLevels.png)](figs/Blausen_0342_ElectronEnergyLevels.png){#fig:bohr 
width=40%}

Sous l'effet du frottement (entre autres) un atome peut perdre ou gagner des électrons.
Il devient ainsi positivement ou négativement chargé (respectivement),
et est appelé un *ion*. Les atomes dans un solide ont une structure
cristalline (ils ne peuvent quasiment pas bouger). De plus, dans des isolants,
les électrons sont également fortement attachés à leurs noyaux, alors que dans
des conducteurs, ils sont libres de se mouvoir à la surface du solide. Ainsi,
lorsqu'on frotte un isolant (un ballon) avec un autre isolant (les cheveux),
des électrons sont transférés de l'un vers l'autre ce qui conduit
à un transfère net de charge. Cette charge nette ne dure pas indéfiniment,
car les électrons en trop sont diffusés dans l'air, attirés par les molécules d'eau
en général.

## Isolants et conducteurs

Si nous sommes en présence de deux objets métalliques, un chargé électriquement
et un autre neutre, et qu'on connecte les deux objets à l'aide
d'un fil métallique, on constate que l'objet non chargé devient rapidement chargé.
À l'inverse, si on connecte les deux objets métalliques avec
un morceau de plastique, la charge de l'objet neutre ne changera pas.

Les objets métalliques sont de bons *conducteurs* d'électricité, alors que
le plastique est un *isolant* (il conduit mal l'électricité). Il existe également
une sorte intermédiaire qui est à mi-chemin entre isolant et conducteur: 
les *semi-conducteurs*. Le silicium entre dans cette catégorie par exemple (le silicium est un composant très important des ordinateurs).
Nous parlerons des semi-conducteurs plus tard dans ce cours.

La différence entre isolant et conducteur au niveau atomique est la suivante.
Les électrons dans un isolant sont très fortement attachés au noyau. Pour un conducteur
en revanche, certains électrons ont un lien beaucoup plus faible avec le noyau
et peuvent se déplacer librement à la surface du matériau conducteur (mais pas s'en détacher).
Ces électrons sont appelés *électrons libres*. Ainsi, un matériau chargé qui entre en contact
avec un conducteur va avoir pour effet de déplacer les électrons de celui-ci.
Si la charge est positive, les électrons se déplaceront vers la charge,
à l'inverse ils s'en éloigneront si la charge est négative.

Pour en revenir à notre exemple du début de la section, lorsqu'un
conducteur neutre, $N$, est mis en contact avec un autre conducteur chargé positivement, $C$,
le conducteur $N$ deviendra également positivement chargé. 
En effet, lorsque $N$ et $C$ sont mis en contact, les électrons de $N$
sont attirés par la charge positive de $C$, et certains passeront de $N$ à
$C$, diminuant la charge nette de $C$ et augmentant la charge positive
de $N$, jusqu'à ce que $N$ et $C$ aient la même charge. Ce processus
est appelé charge par *conduction*, car les deux conducteurs sont en contact
direct.

Si maintenant les deux objets sont rapprochés, mais sans être mis en contact. Les électrons libres ne vont pas quitter le conducteur $N$ pour rejoindre le conducteur $C$. En revanche, les électrons de $N$
seront attirés par le conducteur $C$ et se déplaceront en direction
de $C$, créant ainsi deux zones à l'intérieur de $N$: une chargée négativement proche de $C$, et une positivement éloignée de $C$.
Néanmoins, la charge nette de $N$ reste toujours la même,
c'est à dire nulle. Ce processus est appelé charge par *induction*.

---

Question (Charger un conducteur) #

Pouvez-vous imaginer un processus pour charger un conducteur en utilisant
la charge par induction?

---

---

Réponse (Charger un conducteur) #

Ce processus permet de charger un objet assez facilement.
Pour ce faire, il faut connecter l'objet à l'aide d'un conducteur à la Terre[^8] (à l'aide d'un fil par exemple). Puis, en utilisant la
charge par induction, les électrons vont quitter (ou pénétrer)
le conducteur depuis la Terre. Puis, il suffit de couper le
fil et le tour est joué.

---

## La loi de Coulomb

Dans les précédentes sections, nous avons vu la phénoménologie
de la force que les charges électriques peuvent exercer entre
elles. Ces forces peuvent être attractives ou répulsives, mais
nous ne savons pas encore quelle peut être la magnitude de cette
force. 

---

Question ouverte (Force électrique) #

De quoi dépend la force électrique à votre avis?

---

La force électrique a été étudiée par Charles Coulomb au 18e siècle 
(1780 environ) à l'aide d'une *balance à torsion*. Cette balance
est basée sur le même principe qu'une balance pour la gravitation, mais
adaptée à la force électrique (une vidéo décrivant l'expérience
peut se trouver [sur ce lien](https://bit.ly/3nOgZEN)).

Un axe avec une boule conductrice à une extrémité est suspendue
à un long fil très fin. Le dispositif est enfermé dans une cloche
en verre limitant ainsi les courants d'air. Dans cette cloche,
on peut introduire un autre conducteur chargé. Lorsque les boules sont mises en contact, la charge est répartie entre les deux objet et ils se repoussent. Cette force induit une torsion du fil
et on peut ainsi mesurer l'amplitude de la force. Ainsi, on peut mesurer
la torsion du fil sous l'effet de la force électrique.
En variant la distance de départ entre les charges, et en utilisant
plus d'objets, Coulomb a pu déterminer sa loi reliant la force électrique avec la distance et la charge.

Coulomb énonce que la force électrique
entre deux object de charges $Q_1$, et $Q_2$ est proportionnelle au produit des charges en présence et inversément
proportionnelle au carré de la distance, $r$, qui les sépare[^9].
Cela peut s'écrire sous la forme
$$
F=k\frac{Q_1\cdot Q_2}{r^2},
$$
où $k$ est la constante de proportionnalité. Une autre grandeur
apparaît souvent dans la littérature, la *permittivité du vide*, $\epsilon_0$,
qui est relié à $k$ par la relation
$$
k=\frac{1}{4\pi\epsilon_0},
$$
avec $\epsilon_0=8.85\cdot 10^{-12}\mathrm{C}^2/(\mathrm{N}\cdot \mathrm{m}^2)$.
La force est toujours dans la direction de la ligne reliant
les deux charges. 

---

Exercice (Attraction-répulsion) #

A l'aide de la formule ci-dessus. Pouvez-vous faire un schéma de deux charges, $Q_1$ et $Q_2$,
ainsi que de la force de $Q_1$ sur $Q_2$ et de $Q_2$ sur $Q_1$ dans les cas où:

1. $Q_1>0$ et $Q_2>0$.
2. $Q_1>0$ et $Q_2<0$.
3. $Q_1<0$ et $Q_2>0$.
4. $Q_1<0$ et $Q_2<0$.

---

Si les deux charges ont le même signe, la force est
répulsive (la force éloigne les charges), si les deux charges ont un signe opposé, la force est attractive (la force attire les charges l'une vers l'autre).

---

Question (Action-réaction) #

Est-ce que la loi de Coulomb est compatible avec la troisième loi de Newton (principe d'action-réaction)?

---

---

Réponse (Action-réaction) #

On constate que la loi de Coulomb est effectivement compatible
avec la troisième loi de Newton (encore heureux!). En effet,
l'amplitude de la force est la même quelque soit la charge ($Q_1$ ou $Q_2$) de l'objet que nous considérons, et les forces sont également opposées en direction étant donnée qu'elles sont
répulsives ou attractives.

---

---

Remarque (Force de gravitation) #

On constate que la loi de Coulomb est très similaire à la
loi de gravitation universelle pour deux masses $m_1$, $m_2$,
séparée par une distance $r$
$$
F=G\frac{m_1\cdot m_2}{r^2},
$$
où $G$ est la constante de gravitation universelle.
Une différence fondamentale est que la gravitation
est une force uniquement attractive, alors que la force de Coulomb
peut-être attractive ou répulsive.

---

L'unité de la charge électrique est le *Coulomb*, $[\mathrm{C}]$.

---

Question (Unités de $k$) #

Quelles sont les unités de la constante $k$?

---

---

Réponse (Unités de $k$) #

En SI la constante $k$ a pour valeur
$$
k=8.988\cdot 10^9\ \frac{\mathrm{N}\cdot \mathrm{m}^2}{\mathrm{C}^2},
$$
où $\mathrm{C}$ est le *Coulomb*, l'unité de la charge électrique.

---

Pour avoir une idée de ce que représentent ces grandeurs,
voyons quelle force exerceraient entre elles deux charges
d'un Coulomb séparées d'un mètre:
$$
F\cong 9\cdot 10^9\frac{\cdot 1\cdot 1}{1^2}=9\cdot 10^9\ \mathrm{N}.
$$
Cela correspond au poids d'un objet de presque $10^9\ \kg$!
On voit qu'un Coulomb est une charge gigantesque qu'on ne rencontre pas fréquemment dans la nature. Typiquement, les charges sont plutôt de l'ordre du $\mu C$ (soit $10^{-6}$ Coulombs).

L'unité élémentaire de la charge, est la charge d'un proton ou d'électron, notée $e$: la *charge élémentaire*. Elle vaut
$$
e=1.6022\cdot 10^{-19} \mathrm{C}.
$$
Ici $e$ est positive et correspond donc à la charge d'un
proton, alors que $-e$ est la charge de l'électron.

---

Question (Charge élémentaire) #

Quelle conséquence y a-t-il à avoir une charge élémentaire?
Toutes les charges sont-elles possibles?

---

---

Réponse (Charge élémentaire) #

L'existence d'une charge élémentaire a comme conséquence
que la charge est "quantisée": elle n'est exprimable qu'en
multiples entiers de $e$ ($e$, $2e$, 3$e$, ...). Il est 
ainsi impossible d'avoir une charge qui soit $12889283.
512\cdot e$. Pour des usages pratiques, on voit néanmoins
que cette discrétisation n'a pas d'implication directes:
il faut environ $10^{13}$ électrons pour faire $1\mu\mathrm{C}$. On a donc l'impression à l'échelle humaine
que la charge est une quantité *continue*. En revanche à
des échelles nanoscopies (la taille des circuits des micro-processeurs par exemple) l'effet de la quantisation
devient visible et même problématique (on a atteint la limite de réduction de la taille des circuits imprimés classiques à cause de *l'effet tunnel*).

---

L'équation de Coulomb s'applique à des charges **ponctuelles** ou au moins
la taille ds objets chargés est beaucoup plus faible que les distances entre les objets.
Cela permet de négliger la distribution des charges dans des objets qui pourrait être 
non-uniforme. Par ailleurs, cette équation est valable quand les charges sont stationnaires
car d'autres forces entrent en jeu lorsque les charges sont en mouvement, mais cela
dépasse le cadre de ce cours. Ici nous nous intéressons donc à **l'électrostatique**
et donc l'équation de Coulomb donne la **force électrostatique**.

---

Exemple (force électrique sur un proton) #

Déterminer la valeur, direction et orientation de la force électrique entre un proton
et un électron, de charges $Q_1=-e$ et de charge $Q_2=+e$ dans un atome d'hydrogène
en supposant que l'électron et le proton sont à une distance de $r=0.5\cdot 10^{-10}\mathrm{m}$.

Solution (force électrique sur un proton) #

La norme de la force se détermine aisément avec l'équation de Coulomb
$$
F=k\frac{Q_1Q_2}{r^2}=\frac{9\cdot 10^9\cdot 1.6^2\cdot 10^{-38}}{0.5^2\cdot 10^{-20}}\cong 9\cdot 10^{-8}\ \mathrm{N}.
$$
Cette force va dans la direction reliant le proton et l'électron, et est attractive car les forces sont opposées.

---

---

Exemple (Symétrie) #

Soient deux forces $Q_1=10\mu\mathrm{C}$ et $Q_2=100\mu\mathrm{C}$ séparées par une distance $r$. Quelle charge ressent la plus grande force?

Solution (Symétrie) #

La force ressentie par les deux forces est la même. En effet,
$$
F_{12}=k\frac{Q_1Q_2}{r^2}=k\frac{Q_2Q_1}{r^2}=F_{21}.
$$

---

La loi de Coulomb décrit l'intéraction entre deux charges.
En présence de plusieurs charges, nous pouvons appliquer
le *principe de superposition*, et comme nous l'avons fait
pour la force de gravitation, et considérer les forces deux
par deux comme des vecteurs. Ainsi, si nous avons un système 
de trois charges, $Q_1$, $Q_2$, et $Q_3$, la charge $Q_1$
ressent la somme de la force $Q_2\rightarrow Q_1$ et $Q_3\rightarrow Q_1$.

## Deux exercices

Les exercices suivants sont très similaires à ce que nous avons fait
avec les forces au chapitre précédent. L'unique différence, c'est que les forces
sont obtenues avec la loi de Coulomb.

---

Exemple (Sur une ligne) #

Soient trois particules chargées, $Q_1$, $Q_2$, et $Q_3$ alignées de gauche à droite (voir @fig:charges_aligned).
Calculer la force exercée sur $Q_3$ (la particule la plus à droite) si les charges sont
données par
$$
Q_1=-8\mu\mathrm{C},\quad Q_2=3\mu \mathrm{C},\quad Q_3=-3\mu\mathrm{C},
$$
et que les distances sont de
$$
r_{12}=0.3\ \mathrm{m},\quad r_{23}=0.2\ \mathrm{m}.
$$
Ensuite calculer les forces agissant sur $Q_1$ et $Q_2$.

![Illustration des charges alignées.](figs/charges_aligned.svg){#fig:charges_aligned width=100%}


Solution (Sur une ligne) #

Par le principe de superposition, on a que la force résultante, $\vec F$ que ressent $Q_3$ est donnée par
$$
\vec F=\vec F_{2\rightarrow 3}+\vec F_{1\rightarrow 3}.
$$
La loi de Coulomb nous donne immédiatement $F_{2\rightarrow 3}$ et $F_{1\rightarrow 3}$
\begin{align}
F_{2\rightarrow 3}&=k\frac{Q_2Q_3}{r_{23}^2}\cong
2.02\mathrm{N},\\
F_{1\rightarrow 3}&=k\frac{Q_1Q_3}{r_{13}^2}\cong
0.86\mathrm{N}.
\end{align}
La charge $Q_3$ étant négative la force de $Q_1$ est répulsive, alors que  celle de $Q_2$ est attractive.
On a donc finalement
$$
F=-F_{2\rightarrow 3}+F_{1\rightarrow 3}=-1.16\mathrm{N},
$$
et la force pointe vers la gauche.

Les force sur $Q_1$ et $Q_2$ sont à faire pour vous comme des grand·e·s.

---

Cet exercice nous montre une propriété importante de la 
force électrique. La charge $Q_2$ ne masque pas du tout
la charge $Q_1$. En effet, la force que $Q_1$ applique sur $Q_3$ est la même que si $Q_2$ n'était pas là.

---

Exemple (Avec des vrais vecteurs) #

Soient trois charges comme sur la @fig:charges. Calculer la force électrostatique résultante
sur $Q_3$ dûes aux charges $Q_1$ et $Q_2$.

Ajouter une charge $Q_4=-50\mu\mathrm{C}$ de telle façon à ce que la force sur $Q_3$ soit nulle. Quelle doit être sa position?

![Le positionnement des charges.](figs/charges.svg){#fig:charges width=80%}

Solution (Avec des vrais vecteurs) #

Cet exercice se résout de façon très similaire à l'exercice précédent, simplement que le problème est bi-dimensionnel. La force résultante sur $Q_3$ est donnée
par
$$
\vec F=\vec F_{2\rightarrow 3}+\vec F_{1\rightarrow 3}.
$$
Les normes de $\vec F_{2\rightarrow 3}$ et $\vec F_{1\rightarrow 3}$ se calculent avec la loi de Coulomb
\begin{align}
F_{2\rightarrow 3}&=k\frac{Q_2Q_3}{r_23^2}\cong 325\mathrm{N},\\
F_{1\rightarrow 3}&=k\frac{Q_1Q_3}{r_13^2}\cong 140\mathrm{N}.
\end{align}
Avec vos talents de trigonométrie, on a ensuite que les vecteurs sont donnés par
\begin{align}
\vec F_{1\rightarrow 3} &= F_{1\rightarrow 3}\vectwo{\cos 30}{-\sin 30}=\vectwo{120}{-70}\mathrm{N},\\
\vec F_{2\rightarrow 3} &= F_{2\rightarrow 3}\vectwo{\cos 90}{\sin 90}=\vectwo{0}{325}\mathrm{N}.
\end{align}
Et on a finalement
$$
\vec F=\vectwo{120+0}{325-70}=\vectwo{120}{255}\mathrm{N}.
$$
On peut en déduire la norme $||\vec F||$ à l'aide du théorème de Pythagore
$$
||\vec F||=\sqrt{F_x^2+F_y^2}\cong 280\mathrm{N}.
$$
L'orientation, $\theta$, de $\vec F$ se calcule également avec un peu de trigonométrie
$$
\tan\theta=\frac{F_y}{F_x}=\frac{255}{120}=2.13 \Leftrightarrow \theta=65^\circ.
$$
Afin de déterminer l'endroit où il faut placer $Q_4$, il faut que la somme de $\vec F$ avec $\vec F_{4\rightarrow 3}$ soit nulle. On doit donc avoir que la norme de ces deux forces doivent être égales et que leur direction doivent être opposées. Cela nous donne deux conditions
\begin{align}
F=F_{4\rightarrow 3},\\
\theta_4=360-\theta.
\end{align}
Nous connaissons déjà la direction de la force et donc dans quelle direction se trouvera $Q_4$ (la direction pointée par l'angle $\theta_4$). La première condition nous permet finalement de calculer la distance entre $Q_3$ et $Q_4$, $r_{34}$
\begin{align}
F&=k\frac{Q_3Q_4}{r_{34}^2}=\frac{9\cdot 10^9\cdot 50\cdot 10^{-6}\cdot 65\cdot 10^{-6}}{r_{34}^2},\nonumber\\
r_{34}^2&=k\frac{Q_3Q_4}{F}=\frac{29.2}{280},\nonumber\\
r_{34}&=0.32\mathrm{m}.
\end{align}

---

Encore une fois on utilise le principe de superposition
pour déterminer l'emplacement de la nouvelle charge comme si les charges $Q_1$ et $Q_2$ n'existaient pas.

---

Exercice (Flotter) #

Soient deux charges, $Q$ et $-Q$ qui sont à une distance $r$ l'une de l'autre. Pouvez-vous trouver l'endroit où
on peut placer une charge $Q$ entre les deux pour qu'elle ne ressente aucune force? Même question mais pour les deux charges initiales ayant une charge positive.

---

## Le champs électrique

Les forces habituelles que nous exerçons ou subissons tous les jours sont souvent dites
de "contact". Ainsi, lorsque notre main tiens un stylo, que nous donnons un coup de pied dans un ballon, ... il y a un contact direct entre les objets. La force de gravitation et la force électrique ne fonctionnent pas comme cela, elles agissent *à distance* sans que des objets se touchent. Cette notion est un peu compliquée à appréhender. On la représente à l'aide d'un **champs**. Le champs électrique s'exerce vers l'extérieur d'une charge, $Q$, dans toutes les directions et remplit tout l'espace (voir @fig:electric_field). 

![Schéma du champs électrique généré par une charge $Q$ et mesuré à l'aide d'une charge négligeable $q$.](figs/electric_field.svg){#fig:electric_field width=40%}

Si une seconde charge, $q$, est placée quelque part proche de la charge initiale, elle va intéragir avec le champs électrique de celle-ci. Cette intéraction
est la source de la force électrostatique exercée par $Q$ sur $q$.

Le champs électrique d'une charge $Q$ peut être mesuré à l'aide d'une charge test $q$. La charge test doit être suffisamment petite pour avoir un effet négligeable sur le champs électrique de $Q$. On peut donc ainsi en baladant $q$ dans l'espace autour de $Q$, mesurer la force, $\vec F$, exercée par $Q$ sur $q$. Le champs électrique $\vec E$ est ensuite défini comme la force exercée sur $q$ divisée par $q$
$$
\vec E=\frac{\vec F}{q}.
$$
De la loi de Coulomb, on peut donc déduire que le champs électrique autour d'une charge $Q$,
mesurée à l'aide d'une charge $q$ sera donné par
$$
E=k\frac{Qq}{r^2}\frac{1}{q}=k\frac{Q}{r^2}=\frac{1}{4\pi \epsilon_0}\frac{Q}{r^2}.
$$
On voit donc que $E$ ne dépend que de $Q$ et plus de $q$.
Le champs électrique est une quantité ne dépendant que de la charge qui l'émet. Il décroît comme le carré de la distance
entre la charge et le point de la mesure.

Si à présent on inverse le problème et qu'on nous donne un champs électrique $\vec E$, et qu'on aimerait connaître la force dûe à ce champs électrique sur une charge $q$ quelconque. On aurait
$$
\vec F=\vec E q.
$$

---

Exemple (Photocopieuse) #

Une photocopieuse fonctionne en arrangeant des charges 
(suivant la forme de ce qu'on veut copier)
sur la surface d'un rouleau et ensuite en disposant
gentiment l'encre sèche, des particules chargées négativement (le toner), sur le rouleau pour qu'elles s'y attachent. Ainsi, le toner s'attache en suivant
la forme des particules chargées et est ensuite chauffé
lorsqu'il se trouve au contact du papier pour y être transféré. En supposant que chaque particule de toner a un excès de 20 électrons et que leur masse est de $9\cdot 10^{-16}\mathrm{kg}$. Quelle doit être le champs électrique du rouleau pour que les particules restent attachées au rouleau, s'il faut au moins une force de deux fois leur poids pour qu'elles ne s'en détachent pas?

Solution (Photocopieuse) #

La charge de chaque particule de toner est de $q=20e$. La force électrostatique qui s'applique sur chacune d'entre elles est de $F=qE$. De plus, on nous dit que pour que le toner ne se détache, la force électrostatique doit être au moins égale à deux fois le poids de chaque particule. Il vient donc
$$
q\cdot E=2\cdot m\cdot g.
$$
On résout pour $E$ et on trouve
$$
E=\frac{2mg}{q}=\frac{2\cdot 9\cdot 10^{-16}\cdot 9.8}{20\cdot 1.6\cdot 10^{-19}}=5.5\cdot 10^3\mathrm{N}/\mathrm{C}.
$$

---

---

Exercice (Charge ponctuelle) #

Calculer l'amplitude et la direction du champs électrique émis par une charge
ponctuelle de charge $Q=-5\cdot 10^{-6}\ \mathrm{C}$ à un point $P$, se trouvant
à $50\cm$ à droite de la charge $Q$.

<!-- Solution Cachée (Charge ponctuelle) #

La loi de Coulomb donne l'amplitude du champs électrique et le signe de la charge sa direction.
On a donc
$$
E=k\frac{Q}{r^2}=\frac{9\cdot 10^9\cdot 5\cdot 10^{-6}}{0.5^2}=1.8\cdot 10^5\mathrm{N/C}.
$$
La direction du champs électrique pointe dans la direction de la charge.
Étant donné que nous avons défini le champs électrique comme agissant
sur une charge test **positive**, la force sera ici attractive et
aura comme conséquence que le champs électrique pointera dans
la direction de la charge $Q$. Si la charge avait été positive,
la direction du champs électrique aurait été inversée. -->

---

Le champs électrique en un point de l'espace émis par plusieurs charges
sera la sommes des champs électriques émis par chacun des charges indépendamment des autres, en vertu du **principe de superposition**. Ce principe a été confirmé expérimentalement vérifié.

---

Exemple (Champs électrique entre deux charges) #

Deux charges ponctuelles, $Q_1$ et $Q_2$, sont séparées par une distance de $1\m$.
Si $Q_1=200\mu\mathrm{C}$ et $Q_2=-400\mu\mathrm{C}$.

1. Déterminer la direction et l'amplitude du champs électrique à un point $P$ entre les deux charges, avec $P$ se trouvant à $30\cm$ de $Q_1$ et $70\cm$ de $Q_2$.
2. Si nous plaçons un électron au repos en $P$ ($m=9\cdot 10^{-31}\kg$). Quelle sera sont accélération au moment où il est libéré?

Solution (Champs électrique entre deux charges) #

1. Le champs électrique en $P$ est rien d'autre que la somme des champs électriques de chaque 
charge prises individuellement. Si $Q_1$ est à gauche et $Q_2$ à droite, on a que $E_1$ pointe vers la droite et $E_2$ vers la droite également. Avec la loi de Coulomb et le principe de superposition, on a
$$
E=E_1+E_2=k\left(\frac{Q_1}{r_1^2}+\frac{Q_2}{r_2^2}\right)=9\cdot 10^9\left(\frac{2\cdot 10^{-4}}{0.3^2}+\frac{4\cdot 10^{-4}}{0.7^2}\right)=2.73\cdot 10^7\N/\mathrm{C}.
$$
2. L'accélération de l'électron sera donnée par la deuxième loi de Newton:
$$
F=m\cdot a,
$$
avec $F=q\cdot E$. Il vient donc
$$
a=\frac{F}{m}=\frac{qE}{m}=\frac{1.6\cdot10^{-19}\cdot 2.73\cdot 10^7}{9\cdot 10^{-31}}=4.85\cdot 10^{18}m/s^2.
$$

---

---

Exercice (Carré) #

Soient quatre charges de même amplitude mais de signe pouvant être différent et placées
sur les 4 coins d'un carré. Quel arrangement va produire le champs électrique le plus élevé
au centre du carré?

1. Les 4 charges positives?
2. Les 4 charges négatives?
3. Trois positives, une négative?
4. Trois négative une positive?
5. Deux positives, deux négatives?

---

---

Exercice (Avec des vrais vecteurs) #

Soient trois charges comme sur la @fig:charges. Calculer le champs électrostatique 
à la position $Q_3$ dûes aux charges $Q_1$ et $Q_2$.

---

## Les lignes de champs électrique

Le champs électrique est représenté par un vecteur, et on parle de *champs vectoriel*
pour le représenter. Cela signifie qu'à chaque point de l'espace le champs électrique
va associer un vecteur, qui aura l'amplitude et la direction du champs électrique en ce point
(voir @fig:champ_e).
Dessiner de tels vecteurs peut être facilement fastidieux et peut lisible lorsque la
quantité de vecteurs devient trop grande.

![Champs de vecteurs représentant de champs électrique d'une charge positive. 
Source: Wikipédia, 
<https://bit.ly/3bTIJDx>.](figs/langfr-1024px-E_FieldOnePointCharge.png){#fig:champ_e 
width=80%}


Pour visualiser un champs électrique, on utilise en général une série de lignes
pour indiquer la direction du champs électrique (on s'intéresse plus à sont amplitude
dans ce cas). On parle alors des **lignes de champs électrique** et sont dessinées
pour indiquer la direction de la force dûe à des charges électriques sur une charge test
*positive*. Cette convention implique que les lignes de champs sont **sortantes** pour une
charge *positive* et *entrantes* pour une charge négative (voir @fig:plus_minus_field)

![Lignes de champs électrique reliant en présence de deux charges positives 
(gauche) et une charge négative et une positive (droite). Les lignes de champs 
sont sortantes de la charge positive, et entrantes dans la charge négative. 
Source: Wikipédia, 
<https://bit.ly/3dPsUk2>.](figs/Camposcargas.PNG){#fig:plus_minus_field 
width=80%}

---

Exercice (Charge seule) #

Dessiner les lignes de champs pour un charge positive seule et une charge négative seule.

---

On ne dessine qu'une quantité limitées de lignes de champs, bien qu'il en existe une infinité.
La *densité* de lignes de champs est proportionnelle à l'intensité du champs
électrique dans cette région de l'espace (plus elles sont denses plus le champs électrique
est important). Cette propriété des lignes de champs électrique sera très utile plus tard il
faut donc bien s'en souvenir.

---

Question (Champs électrique entre deux plaques de signes opposés) #

Soient deux plaque infinies, à quoi vont ressembler les lignes de champs électrique?

---

---

Réponse (Champs électrique entre deux plaques de signes opposés) #

Les lignes de champs sont parallèles entre elles, sortantes de la plaque positive et entrantes dans la plaque négative. Pour des raisons de symétrie, on peut assez facilement se convaincre
que les lignes de champs sont perpendiculaires aux plaques. En effet, une charge test
placées entre deux plaques infinies ressentirait une force symétrique 
de la part de chaque plaque et irait donc dans la direction perpendiculaire aux plaques.

Dans le cas où les plaques ne sont pas infinies, les lignes de champs s'incurvent au
fur et à mesure qu'on s'approche des extrémités des plaques (voir @fig:plaques_non_sym)

![Lignes de champs dans le cas de deux plaques chargées de longueur finies et 
de signes opposés. On constante que les lignes de champs s'incurvent aux 
extrémités. Source: Wikipédia, 
<https://bit.ly/3b2qIUx>](figs/VFPt_capacitor-square-plate.svg){#fig:plaques_non_sym 
width=80%}

---

## Le champs électrique dans des conducteurs

A présent, nous voulons discuter les propriétés des conducteurs
à la lumière du concept des champs électriques.

Dans le cas statique, c'est à dire quand les charges sont au repos, le champs
électrique dans un conducteur est **nul**. En effet, s'il existait un champs électrique
dans le conducteur, les électrons libres se mettraient en mouvement (sous l'influence
du champs électrique). Les électrons se positionneraient de telle façon que le champs
devienne nul (et qu'ainsi ils ne bougent plus).

Cette propriété a un certain nombre de conséquences intéressantes.

![Le champs électrique à l'intérieur d'un conducteur est nul. Les charges se déplacent pour se placer à la surface du conducteur et annulent exactement le champs électrique externe.](figs/field_conductor.svg){#fig:field_conductor width=80%}

1. Toute charge nette dans un conducteur se distribue à sa surface. Pour des charges
négatives, on peut assez aisément imaginer que les électrons essaient de s'éloigner les plus
possible les uns des autres, et se dirigeront vers la surface du conducteur (voir @fig:field_conductor).
2. Si une charge $Q>0$ est entourée par un anneau conducteur (la charge er le conducteur ne se touchent pas). Comme il ne peut y avoir de lignes de champs dans l'anneau, les charges négatives du se placeront sur la surface interne de l'anneau alors que les positives iront sur la face externe. Comme la charge nette du conducteur est nulle, la charge sur la surface interne du conducteur doit être de $-Q$ et sa surface externe doit être $+Q$. Ainsi, les lignes
de champs électriques se "recréent" à l'extérieur du conducteur, bien qu'il n'en existe pas é l'intérieur (voir @fig:field_conductor).
3. Le champs électrique à l'extérieur d'un conducteur forme **toujours** un angle de $90^\circ$ avec la surface. En effet, si l'angle n'était pas perpendiculaire, la composante parallèle du champs électrique déplacerait les charges  le long de la surface (car une force s'appliquerait sur elles) jusqu'à ce qu'elles atteignent une position d'équilibre où elles ne bougent plus (où plus aucune force ne s'exercent sur elles). Et dans cette position le champs électrique est perpendiculaire.

Ces propriétés ne s'appliquent qu'aux conducteurs. Les isolants n'ayant pas d'électrons libres,
ceux-ci ne peuvent pas se déplacer librement. Un champs électrique peut donc exister à
l'intérieur d'un isolant. De plus le champs électrique à la surface d'un isolant peut ne pas être perpendiculaire.

---

Question (Cage de Faraday) #

Une boîte en métal est placée entre deux plaques parallèles chargées électriquement
comme sur @fig:metal_box.

![Deux plaques charges parallèles et une boîte entre les deux.](figs/metal_box.svg){#fig:metal_box width=80%}

Quel sera le champs électrique à l'intérieur de la boîte?

---

--- 

Réponse (Cage de Faraday) #

Il y a deux cas de figure:

1. La boîte est "pleine" (remplie de métal). Dans ce cas, que nous avons déjà discuté
les électrons libres du métal se redistribuent dans le métal afin de faire en sorte que
le champs électrique soit nul à l'intérieur.
2. La boîte en "vide" et c'est un peu plus complexe, mais le résultat est le même.
Le champs externe ne sera pas modifié, car les électrons externes se redistribueront
exactement de la même manière que pour la boîte pleine. Cela entraîne que le champs à l'intérieur
sera également nul, car la distribution externe des électrons sera la même que dans le cas de la boîte
pleine. On voit qu'une cage métallique est bon moyen d'isoler un volume d'un champs électromagnétique externe à la boîte (voir @fig:metal_box_sol). Ainsi, une voiture frappée par la foudre protégera ses occupants tout comme un avion ne sera en général que légèrement impacté s'il reçoit la foudre.
Contrairement à être sous un arbre pendant un orage...

![Le champs électrique à l'intérieur de la boîte est nul. En effet les charges se répartissent à la surface du conducteur pour y annuler le champs.](figs/metal_box_sol.svg){#fig:metal_box_sol width=80%}

---

## La loi de Gauss

La loi de Gauss (célèbre mathématicien et physicien de 18-19e siècle) fait intervenir
le concept de **flux électrique**. Cette quantité est la quantité de champs électrique
passant au travers d'une **surface**. L'équivalent pour un liquide serait le **débit** 
(la quantité de liquide passant au travers d'une surface).
Pour un champs électrique *uniforme*, $\vec E$, passant au travers d'une surface $S$ (voir @fig:flux_a),
comme sur @fig:flux_a le flux, $\Phi_E$ est donné par
$$
\Phi_E=E\cdot S\cdot \cos(\theta),
$$
ou $\theta$ est l'angle entre la normale de la surface et la direction du champs électrique.

![Le champs $\vec E$ passant au travers de la surface $S$.](figs/flux_a.svg){#fig:flux_a width=80%}

Le flux électrique peut être vu de façon équivalent comme la projection de la surface sur
la direction du champs électrique ou la projection du champs électrique sur
le vecteur normal de la surface.
$$
\Phi_E=E_\perp\cdot S=E\cdot S_\perp=E\cdot S\cos \theta,
$$
où $S_\perp=S\cdot \theta$ est la projection de $\vec S$ sur la direction du champs électrique (la surface $S$ multipliée par le vecteur unitaire perpendiculaire à la surface) et $E_\perp$ la projection de $\vec E$ sur la direction normale à la surface $S$.

Comme nous l'avons discuté plus haut, le champs électrique se représente
avec les lignes de champs. Plus le champs est intense, plus les lignes sont
rapprochées. Ainsi le nombre de le champs électrique $E$ est proportionnel à
la densité des lignes traversant $S_\perp$,
$$
N\sim E\cdot S_\perp=\Phi_E.
$$
Le théorème de Gauss implique le flux total de champs électrique sur une surface **fermée**.
Prenons un cas simplifié pour commencer, où la surface fermée est un *cube*. On souhaite calculer
le flux total passant u travers de la surface du cube (voir @fig:flux_cube) et le champs électrique est *uniforme*. 

![Le champs $\vec E$ passant au travers de la surface d'un cube. Chaque surface des facettes du cube est numérotée $\Delta S_1$, $\Delta S_2$, $\Delta S_3$, ..., $\Delta S_6$.](figs/flux_cube.svg){#fig:flux_cube width=80%}

Pour ce faire nous numérotons les facettes du cube $\Delta S_1$, $\Delta S_2$, ..., $\Delta S_6$ (voir @fig:flux_cube),
et l'angle entre le champs électrique et chacune des normales des facettes correspondantes, $\theta_1$, $\theta_2$, ..., $\theta_6$.
Le flux total sera donné par
\begin{align}
\Phi_E&=\Delta S_1 E \cos\theta_1+\Delta S_2 E \cos\theta_2+\Delta S_3 E \cos\theta_3+\Delta S_4 E \cos\theta_4+\Delta S_5 E \cos\theta_5+\Delta S_6 E \cos\theta_6\nonumber\\
&=\sum_{i=1}^6E\Delta S_i\cos\theta_i.
\end{align}
Comme nous avons vu plus haut, le nombre de lignes de champs
partant d'une charge positive et arrivant sur une charge négative
sont proportionnelles à la charge. Ainsi le nombre **net** (la différence entre celle entrantes
et celles sortantes) de lignes
de champs pointant vers l'extérieur d'une surface fermée est proportionnel
à la charge à l'intérieur de la surface, $Q_\mathrm{int}$. La constante de
proportionnalité est $1/\epsilon_0$. On a donc finalement
$$
\sum_i E\Delta S_i\cos\theta_i=\frac{Q_\mathrm{int}}{\epsilon_0}.
$$
En l'occurrence, on a aucune charge à l'intérieur du cube et on peut voir assez facilement
que dans le cas où $E$ est homogène et aligné avec une face du cube, on a:
$$
E\cos \pi + E\cos 0+ 4\cos\pi/2= -E+E=0.
$$
En fait cette relation se généralise à n'importe quelle surface fermée.
Si on numérote les $N$ facettes d'une surface **fermée**, $\{\Delta S_i\}_{i=1}^N$,
et l'angle entre la normale de la $i$-ème facette avec le champs $E$, $\{\theta_i\}_{i=1}^N$
on peut écrire la **loi de Gauss**
$$
\sum_i^N E\Delta S_i\cos\theta_i=\sum_i^N E_{i,\perp}\Delta S_i=\frac{Q_\mathrm{int}}{\epsilon_0},
$$
où $E_{i,\perp}$ est la projection de $\vec E$ sur le vecteur perpendiculaire à
la surface $\Delta S_i$.

---

Exemple (Sphère chargée) #

Une surface conductrice sphérique  de rayon $R_0$ et possédant une 
charge $Q$ distribuée uniformément sur sa surface. Déterminer le champs
électrique

1. À l'extérieur de la surface.
2. À l'intérieur de la surface.

---

---

Solution (Sphère chargée) #

Considérations philosophiques: comme la charge est distribuée de façon
symétrique, le champs électrique doit également être symétrique. Ainsi
la seul façon pour qu'il soit symétrique est qu'il soit en tout point
perpendiculaire à la surface et ne dépendre que de $R$, la distance entre le centre de la sphère et le point de l'espace où on mesure le champs électrique.

On va utiliser la loi de Gauss pour résoudre cet exercice. Pour ce faire nous allons
choisir deux surfaces différentes comme nous allons le voir ci-après.

1. On choisit une surface sphérique, $S_1$, avec $R>R_0$ et concentrique avec la sphère
de départ. Par symétrie, le champs a la même amplitude sur toute la surface $S_1$,
on a donc que $E_{i,\perp}=E$ pour n'importe quelle valeur de $i$. La loi de Gauss
s'écrit donc
$$
\sum_i^N E_{i,\perp}\Delta S_i=E\sum_i^N \Delta S_i=E(4 \pi R^2)=\frac{Q_\mathrm{int}}{\epsilon_0},
$$
où nous avons utilisé que $\sum_i \Delta S_i$ est la surface totale de la sphère de
rayon $R$. Il ne nous reste qu'à résoudre cette équation pour $E$, et il vient
$$
E=\frac{1}{4 \pi epsilon_0}\frac{Q}{R^2}=k\frac{Q}{R^2}.
$$
Ce qui est intéressant car c'est **exactement** le même résultat que pour une charge
ponctuelle, de charge $Q$, qui se trouverait au centre de la sphère.
2. De façon similaire, on peut construire une surface $S_2$ sphérique, concentrique avec
la sphère originale, avec $R < R_0$. On a donc 
$$
E\sum_i^N \Delta S_i=E(4 \pi R^2)=\frac{Q_\mathrm{int}}{\epsilon_0}=0,
$$
car $Q_\mathrm{int}=0$ dans ce cas (toute la charge est sur la surface chargée).
On a donc que le champs à l'intérieur de $S_2$ est nul, et donc le champs à l'intérieur d'une sphère chargée est nul.

---

---

Question (Et si on remplissait la sphère) #

Que se passerait-il si la sphère était pleine?

---

---

Réponse (Et si on remplissait la sphère) #

En fait ce résultat est valide pour n'importe quelle sphère pleine conductrice chargée. En effet, toutes les charges se repousseraient et se répartiraient uniformément sur sa surface.
On se retrouverait dans la même situation que pour la sphère vide. 

---

## Résumé

On a vu plusieurs concepts importants dans ce chapitre.

* La **charge électrique** peut être négative ou positive et qui est toujours **conservée**.
* Les matériaux **isolants** et **conducteurs** qui respectivement conduisent ou pas l'électricité. Contrairement au isolants, les conducteurs possèdent des **électrons libres** qui peuvent se déplacer à l'intérieur d'un solide.
* La charge électrique est **quantisée**: il existe une charge élémentaire, $e$, qui est la charge du proton, $+e$, ou celle de l'électron $-e$.
* Les charges électriques exercent des **forces** les unes sur les autres. Elles sont attractives pour des charges de types différents et répulsives pour les charges de même type.
* La **loi de Coulomb** donne la relation entre la **force électrostatique**, la charge, et la distance entre deux object (respectivement, $Q_1$, $Q_2$, et $r$):
$$
F=k\frac{Q_1Q_2}{r^2}.
$$
* Le **champs électrique** est une quantité existant dans l'espace autour des charges. Il peut être mesuré à l'aide d'une charge test $q$
$$
\vec E=\frac{\vec F}{q}.
$$
* L'amplitude du champs électrique autour d'une charge est
$$
E=k\frac{Q}{r^2}.
$$
* Le champs électrique total autour de plusieurs charges est la somme de toutes les champs électriques. Cela est dû au **principe de superposition**.
* Le **flux** du champs électrique est donné par la quantité donnée par le produit entre la projection du champs électrique sur la normale de la surface, $E_\perp$, multipliée par la surface, $\Delta S$
$$
\Phi_E=E_\perp\cdot \Delta S.
$$
* La **loi de Gauss** nous dit que le flux total au travers d'une **surface fermée** est proportionnel à la charge se trouvant à l'intérieur de la surface.
