# Les circuits électriques

Les circuits électriques sont les composants de bases de toute l'électronique. Nous
allons décrire les circuits les plus simples ici sans aller dans des cas trop avancés.

## Les résistances en série et en parallèle

Quand deux résistances ou plus sont connectées bouts à bouts sur un seul chemin
comme sur la @fig:three_res on dit qu'elles sont branchées **en série**.

![Les résistances $R_1$, $R_2$, $R_3$ sont connectées bout à bout à la source $V$ et traversées par le courant $I$. La chute de voltage au travers des trois résistances est respectivement de $V_1$, $V_2$, $V_3$.](figs/three_res.svg){#fig:three_res width=50%}

Toutes les charges passant par $R_1$ passera aussi par $R_2$ et $R_3$. On
sait donc que le courant sera le même au travers de chaque résistance,
sinon cela impliquerait que les résistances créeraient ou stockeraient des charges
ce qui n'est pas observé dans les circuits
(ou que la conservation de la charge ne serait pas respectée).
Le voltage $V$ (également appelée tension) et on suppose que les fils ont une résistance négligeable (nulle). On a que $V_1$, $V_2$, et $V_3$ sont les différences
de potentiels au travers de chaque résistance. On sait de la loi d'Ohm que
\begin{equation*}
V=RI,
\end{equation*}
et donc 
\begin{equation*}
V_1=R_1 I,\quad
V_2=R_2 I,\quad
V_3=R_3 I.
\end{equation*}

---

Question (Conservation) #

Quelle est la relation entre $V$ et $V_1$, $V_2$, $V_3$?

---

---

Réponse (Conservation) #

L'énergie étant conservée, on a naturellement que
$$
V=V_1+V_2+V_3.
$$

---

On déduit de cette relation que
$$
V=R_1I+R_2I+R_3I=(R_1+R_2+R_3)I,
$$
et donc qu'on peut remplacer les trois résistances par une résistance équivalente (ou nette), où
$$
R_\mathrm{eq}=R_1+R_2+R_3.
$$

---

Exemple (Trois résistances) #

Soit une source de tension qui produit un courant continu de $12\V$ et trois
résistances en série de $3\Omega$ chacune connectées au circuit comme sur la @fig:three_res. Quelle est le courant total dans le circuit?

---

---

Solution (Trois résistances) #

Les trois résistances étant connectées en série, ce circuit est équivalent à
un circuit avec une seule résistance de $R=R_1+R_2+R_3=9\Omega$. En utilisant ensuite
la loi d'Ohm on obtient
$$
I=V/R=12 / 9=4\A.
$$

---

Une autre façon simple de connecter eds résistances sur un circuit est en **parallèle** (voir @fig:three_res_par). Les charges dans ce circuit suivent
trois chemins différents et donc le courant total, $I$, est séparé en trois parties (pas forcément égales), $I_1$, $I_2$, et $I_3$.
$$
I=I_1+I_2+I_3.
$${#eq:isum}
Dans ce type de circuit le courant n'est pas interrompu si une des résistances est
déconnectée (dans le cas où un des appareils que la dite résistance représente arrête de fonctionner par exemple).

![Les résistances $R_1$, $R_2$, $R_3$ sont connectées en parallèle à la source $V$ et traversées par les courants $I_1$, $I_2$, $I_3$.](figs/three_res_par.svg){#fig:three_res_par width=50%}

Quand les résistances sont en parallèle, le voltage qui les traverse doit être le même.
En effet, étant donné qu'on néglige la résistance des fils, deux points connectés
directement entre eux ont le même voltage. Ainsi, on a pour les courants
$$
I_1=\frac{V}{R_1},\quad 
I_2=\frac{V}{R_2},\quad 
I_3=\frac{V}{R_3}. 
$${#eq:i3}
De plus on sait de la loi d'Ohm, qu'on doit pouvoir remplacer les trois résistances
par une unique résistance équivalent, $R_\mathrm{eq}$, avec
$$
I=\frac{V}{R_\mathrm{eq}}.
$${#eq:ipar}
En mélangeant les 3 équations ci-dessus (voir @eq:isum, @eq:i3, et @eq:ipar), on obtient
$$
\frac{V}{R_\mathrm{eq}}=
\frac{V}{R_1}+
\frac{V}{R_2}+
\frac{V}{R_3},
$$
et on déduit
$$
\frac{1}{R_\mathrm{eq}}=
\frac{1}{R_1}+
\frac{1}{R_2}+
\frac{1}{R_3}.
$$

---

Exemple (Trois résistances en parallèle) #

Soit une source de tension qui produit un courant continu de $12\V$ et trois
résistances en parallèle de $3\Omega$ chacune connectées au circuit comme sur la @fig:three_res_par. Quelle est la résistance équivalente?

---

---

Solution (Trois résistances en parallèle) #

Les trois résistances étant connectées en parallèle, on a que la résistance équivalente est
$$
\frac{1}{R_\mathrm{eq}}=\frac{1}{R_1}+\frac{1}{R_2}+\frac{1}{R_3}=1\frac{1}{\Omega}.
$$
La résistance équivalente est donc de $R_\mathrm{eq}=1\Omega$.

---

On voit de l'exemple ci-dessus que la résistance équivalente est moindre que les 
résistances individuelles dans le cas où elles sont branchées en parallèle.
Ceci peut paraître contre intuitif, mais c'est en fait assez raisonnable. Le circuit 
en parallèle permet aux charges de prendre différents chemins. Pour prendre une 
analogie, on peut imaginer le cas d'un barrage contenant de l'eau et deux tuyaux identiques
reliant le barrage à la vallée. Le potentiel gravitationnel en haut du barrage est
le même indépendamment du nombre de tuyaux. Quand on ouvre deux tuyaux on a deux fois plus
d'eau qui s'écoule que si on en ouvre un seul (on a d'une certaines façon la résistance globale qui est divisée par deux). C'est un effet similaire pour
les résistances en parallèle. Par ailleurs, si on ferme les vannes des deux tuyaux l'eau ne s'écoule plus. Cela est équivalent à un **circuit ouvert** (où le circuit ne
se referme pas) où le courant ne peut s'écouler.

---

Question (Série ou parallèle) #

Soient deux ampoules identiques (et avec la même résistance). Quelle configuration
produit le plus de lumière (série ou parallèle)? Dans quelle configuration est-il
plus raisonnable de les brancher dans une voiture?

---

---

Réponse (Série ou parallèle) #

La résistance équivalente est plus faible en parallèle qu'en série, le courant total 
est plus élevé dans le cas parallèle. Ainsi, comme le voltage est le même dans les 2 cas, la puissance totale est plus élevée dans le cas parallèle
$$
P=VI.
$$
De plus, brancher les ampoules en parallèle permet d'avoir une ampoule qui fonctionne 
même si l'autre rend l'âme ce qui est quand même plus sûr.

---

---

Exercice (Résistances multiples) #

Deux résistances de $100\Omega$ sont connectées en parallèle ou en série sur une batterie de $24\V$. Quel est le courant total dans chaque circuit? Et la résistance équivalente?


---

On peut faire évidemment beaucoup plus compliqué. Et on va le faire immédiatement.

---

Exemple (Plein de résistances) #

Soit le circuit de la @fig:complex_res. Si la tension $V=9\V$. 

1. Quel est le courant sort de la source de tension? $
2. Quel est le courant dans la résistance de $6\Omega$?

![Un certain nombre de résitances...](figs/complex_res.svg){#fig:complex_res width=50%}

---

La méthodologie globale pour résoudre ce genre d'exercice, est de déterminer la résistance équivalente du circuit en le décomposant en sous-circuits série/parallèle puis en utilisant la loi d'Ohm.

---

Solution (Plein de résistances) #

1. On commence par calculer la résistance équivalent des résistances $8\Omega$ et $4\Omega$. Ces résistances sont en parallèle. On a donc
$$
\frac{1}{R_\mathrm{eq1}}=\frac{1}{8}+\frac{1}{4}=\frac{3}{8}\frac{1}{\Omega}.
$$
On a donc que $R_\mathrm{eq1}=2.7\Omega$ (voir @fig:complex_res_1)

![Un certain nombre de résitances, moins 1...](figs/complex_res_1.svg){#fig:complex_res_1 width=50%}

Puis vient le temps de calculer la résistance équivalente des résistances de $6\Omega$ et $2.7\Omega$. Ces résistances sont en série, donc il suffit de les sommer et on a $R_\mathrm{eq2}=6+2.7=8.7\Omega$ (voir @fig:complex_res_2)

![Un certain nombre de résitances, moins 2...](figs/complex_res_2.svg){#fig:complex_res_2 width=50%}

On a à présent les résistances de $10\Omega$ et $8.7\Omega$ qui sont en parallèle et on calcule
$$
\frac{1}{R_\mathrm{eq3}}=\frac{1}{10}+\frac{1}{8.7}=0.21\frac{1}{\Omega},
$$
et il vient $R_\mathrm{eq3}=4.8\Omega$ (voir @fig:complex_res_3).

![Un certain nombre de résitances, moins 3...](figs/complex_res_3.svg){#fig:complex_res_3 width=50%}

Finalement, on a trois résistances en série qu'on peut simplement sommer et il vient
$$
R_\mathrm{eq}=0.5+5+4.8=10.3\Omega.
$$

On peut à présent calculer le courant dans le circuit avec la loi d'Ohm
$$
V=R_\mathrm{eq}I\Leftrightarrow I=\frac{9}{10.3}=0.87\A.
$$

2. Le courant dans la résistance de $6\Omega$ doit être la même que dans la branche correspondant à $R_\mathrm{eq2}$. On doit encore calculer la tension $V_2$ aux bornes du sous-circuit du haut. On a que
$$
V=V_1+V_2+_3\Leftrightarrow V_2=V-V_1-V_3=V-(0.5+5)\cdot 0.87=4.3\V.
$$
Et finalement que 
$$
I=\frac{4.3}{8.7}=0.48\A.
$$

---



Pour des circuits beaucoup plus compliqués que ceux vus ici, il faut noter qu'il y a un ensemble
de règles qu'on peut appliquer pour déterminer le courant dans un circuit: les **lois de Kirchhoff**. Il s'agit d'un certain nombre de règles très pratiques qui sont des applications des lois de conservation que nous avons déjà vues.

Le première loi de Kirchhoff est basée sur la loi de conservation de la charge électrique. Elle dit que:

À une intersection, la somme de tous les courants entrant dans l'intersection, doit être égale à la somme des courants quittant l'intersection.

Pour résumer, tout ce qui entre à une intersection doit en sortir (sinon ça voudrait dire qu'il y a une fuite ou une source quelque part). Par exemple sur la figure @fig:complex_res_current, on voit qu'à l'intersection $a$, on a le courant $I_1$ qui est entrant, et les courant $I_2$ et $I_3$ qu sont sortants. Ainsi on a $I_1=I_2+I_3$.

![Illustration de la 1e loi de Kirchhoff](figs/complex_res_current.svg){#fig:complex_res_current width=50%}

La seconde loi de Kirchhoff, est une application de la conservation de l'énergie. Elle dit que sur n'importe quelle chemin fermé, le changement de potentiel doit être nul.

Ainsi sur la @fig:two_res_kirch, on a deux résistances, $R_1$ et $R_2$, ainsi qu'ûn potentiel $V$. Si on démarre du point $a$, on a un potentiel $V$ qui est inchangé. Puis au point $b$, avant $R_1$, on a toujours le même potentiel. Au point $c$, on a une première chute de potentiel, car $R_1$ est passée par là. Puis en $d$ on atteint un potentiel nul (toute l'énergie a été consommée) après avoir passé $R_2$. Le potentiel en $e$ est toujours nul. Puis on repasse par la batterie, et on revient en $a$ pour fermer la boucle. En $a$ on a avoir à nouveau un potentiel $V$ et ainsi on voit que le changement de potentiel est nul.

Nous avons déjà analysé de tels circuits précédemment. On si $V$, $R_1$ et $R_2$ sont donnés, nous avons que 
\begin{align}
V=(R_1+R_2)I,\nonumber\\
I=\frac{V}{R_1+R_2}.
\end{align}
La charge et le courant étant conservés, on a que le courant passant par $R_1$ et 
$R_2$ est toujours le même. On a donc que $V_{cb}=-IR_1$ et $V_{dc}=-IR_2$ (contrairement $V$ qui lui est positif). Ces deux voltage sont *négatifs* car ils vont faire baisser le potentiel. On a donc finalement que
$$
V+V_{cb}+V_{dc}=0.
$$


![Illustration de la 2e loi de Kirchhoff](figs/two_res_kirch.svg){#fig:two_res_kirch width=50%}

## Les circuits contenant des capacités en parallèle ou en série

Comme les résistances, les capacités peuvent être placée en série ou en parallèle.
Pour le cas parallèle (voir @fig:three_cap_par) chaque capacité est soumise à la même
différence de potentiel $V$. Ainsi les 3 capacités ont les charges
$$
Q_1=C_1 V,\quad Q_2=C_2 V,\quad Q_3=C_3 V.
$$
La conservation de la charge impose que la charge totale sortant de la source de tension
est donnée par
$$
Q=Q_1+Q_2+Q_3.
$$

![Les résistances $C_1$, $C_2$, $C_3$ sont connectées en parallèle à la source $V$ et accumulent les charges $Q_1$, $Q_2$, $Q_3$.](figs/three_cap_par.svg){#fig:three_cap_par width=50%}

Si nous essayons de décrire ce circuit sous forme de circuit équivalent avec une seule capacité,
$$
Q=C_\mathrm{eq}V,
$$
on voit que
\begin{align}
C_\mathrm{eq}V&=Q_1+Q_2+Q_3,\nonumber
C_\mathrm{eq}V&=(C_1+C_2+C_3)V,\nonumber
C_\mathrm{eq}&=C_1+C_2+C_3.
\end{align}

Considérons maintenant le cas de capacités en série (voir @fig:three_cap). 

![Les résistances $C_1$, $C_2$, $C_3$ sont connectées en série à la source $V$ et accumulent les charges $Q$.](figs/three_cap.svg){#fig:three_cap width=50%}

---

Question (Capacité équivalente) #

Déterminer la capacité équivalente des capacités branchées en série.

Indication: Il faut évaluer $V$ en fonction des chutes de potentiel.

---


---

Réponse (Capacité équivalente) #

Le voltage total au travers de toutes les capacités doit être donné par la somme des voltages au travers de chaque capacité
$$
V=V_1+V_2+V_3.
$${#eq:tot_volt}
On sait aussi que le charge est la même sur chaque capacité (conservation de la charge) et donc
$$
Q=C_1V_1=C_2V_2=C_3V_3.
$$
On peut réécrire @eq:tot_volt comme
$$
\frac{Q}{C_\mathrm{eq}}=\frac{Q}{C_1}+\frac{Q}{C_2}+\frac{Q}{C_3}=Q\left(\frac{1}{C_1}+\frac{1}{C_2}+\frac{1}{C_3}\right).
$$

---

## Les circuits RC

Souvent les capacités et résistances sont connectées en série dans les circuits électriques (voir @fig:rc). C'est même un composant essentiel
dans quasiment tous les circuits du monde.
Ces circuits sont particulièrement utiles quand
les courant n'est pas stationnaire (qu'il dépend du temps). Dans cette section on va analyser les circuits RC dans certains cas particuliers.

![Exemple de circuit RC.](figs/rc.svg){#fig:rc width=50%}

### La charge du condensateur

Quand le circuit RC est *fermé*, le courant s'établit dans le circuit, les charges vont
se mettre en mouvement et s'accumuler sur le condensateur. Au fur et à mesure que les charges
s'accumulent sur le condensateur, la tension entre les plaques augmente aussi (on se souvient
de la fameuse formule $V_C=Q/C$) jusqu'à atteindre la valeur de celle de la source de voltage
(la batterie). A ce moment là, il n'y a plus de courant et plus de différence de potentiel
entre les bornes de la résistance. Le potentiel entre les plaques du condensateur
est donné par l'équation (voir @fig:rc_charge)
$$
V_C=V(1-\exp{(-t/(RC))}).
$$
On voit bien qu'à $t=0$, le potentiel et nul et qu'avec $t\rightarrow \infty$ on tend vers $V_C=V$.

---

Question (Unités...) #

Quelles sont les unités de $R\cdot C$?

---

---

Réponse (Unités...) #

Les unités de la résistance sont des Ohm, $[\Omega]=[\V]/[\A]$ et $[\A]=[\mathrm{C}]/[\mathrm{s}]$, et la capacité, des Farad, $[\mathrm{F}]=[\mathrm{C}]/[\V]$. Il vient que les unités de $R\cdot C$ sont des .... secondes!

---

On appelle
$$
\tau=RC,
$$
la constante de temps du circuit. Cette grandeur donne le temps caractéristique qu'il faut pour que la tension (et la charge) dans le condensateur atteigne $63\%$ de la valeur maximale de la tension de la batterie.

---

Exercice (preuve) #

Pouvez vous prouver cette affirmation (sur les $63\%$ donc)?

---

```{.matplotlib #fig:rc_charge source=true format=SVG caption="Illustration de la charge du condensateur."}
import matplotlib.pyplot as plt
import numpy as np
import math

V = 2.0
R = 1.0
C = 1.0
t = np.linspace(0, 5*R*C, 500)  # Sample data.

plt.figure(figsize=(5, 2.7), layout='constrained')
plt.plot(t, V*np.ones(t.size), label='max')  # Plot some data on the (implicit) axes.
plt.plot(t, V*(1-np.exp(-t/(R*C))), label='charge')  # etc.
plt.xlabel('temps [s]')
plt.ylabel('tension [V]')
plt.title("Tension du condensateur")
plt.legend()
```

---

Question (La charge dans le condensateur) #

Comment calcule-t-on la charge dans le condensateur?

---

---

Réponse (La charge dans le condensateur) #

Comme $Q=V_C\cdot C$, on a immédiatement que
$$
Q=Q_0(1-e^{-t/(RC)}),
$$
avec $Q_0=$V\cdot C$.

---

### La décharge du condensateur


Maintenant que nous avons chargé le condensateur, si nous ouvrons le circuit celui-ci va se décharger. Si nous avons une tension $V_0$ dans le condensateur va se décharger en suivant une exponentielle décroissante (voir #fig:rc_decharge)
$$
V_C=V_0e^{-t/(RC)}.
$$
Comme pour la charge $\tau=RC$, nous donne le temps qu'il faut pour que la tension dans le condensateur diminue de $63\%$ de $V_0$. La charge dans le condensateur suit la même tendance, avec 
$$
Q=Q_0e^{-t/(RC)},
$$
où $Q_0=V_0 C$.


```{.matplotlib #fig:rc_decharge source=true format=SVG caption="Illustration de la charge du condensateur."}
import matplotlib.pyplot as plt
import numpy as np
import math

V = 2.0
R = 1.0
C = 1.0
t = np.linspace(0, 5*R*C, 500)  # Sample data.

plt.figure(figsize=(5, 2.7), layout='constrained')
plt.plot(t, V*np.exp(-t/(R*C)), label='decharge')  # etc.
plt.xlabel('temps [s]')
plt.ylabel('tension [V]')
plt.title("Tension du condensateur")
plt.legend()
```

---

Exemple (Décharge du condensateur) #

Si un condensateur de $C=10\mu \mathrm{F}$ est connectée à une résistance de $R=100\Omega$ et possède une tension de $V_0$. Quand le condensateur se décharge, combien de temps faut-il pour que sa tension tombe à $10\%$ de sa valeur originale?

---

---

Solution (Décharge du condensateur) #

Comme la tension d'un condensateur se diminue comme
\begin{equation*}
V_C=V_0e^{-t/(RC)},
\end{equation*}
et qu'on veut connaître le temps nécessaire pour que $V_C=0.1V_0$, on peut écrire l'équation
\begin{align*}
0.1V_0&=V_0e^{-t/(RC)},\\
0.1&=e^{-t/(RC)},\\
0.1&=e^{-t/(10^{-5}\cdot 100)},\\
\ln{0.1}&=-10^3t,\\
t&=0.0023\s.
\end{align*}

---
